/*-------------------------------------------------------------------------+
| Copyright 2021 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.ext.reuse.ui;

import static org.eclipse.jface.resource.ResourceLocator.imageDescriptorFromBundle;

import org.eclipse.core.runtime.Plugin;
import org.eclipse.jface.resource.ImageDescriptor;
import org.osgi.framework.BundleContext;

/**
 * The activator class controls the plug-in life cycle.
 *
 * @author bergemann
 */
public class ToolingReuseUIActivator extends Plugin {

	/** The plug-in ID. */
	public static final String PLUGIN_ID = ToolingReuseUIActivator.class.getPackage().getName(); // $NON-NLS-1$

	/** The shared instance. */
	private static ToolingReuseUIActivator plugin;

	/** {@inheritDoc} */
	@Override
	public void start(BundleContext context) throws Exception {
		super.start(context);
		plugin = this;
	}

	/** {@inheritDoc} */
	@Override
	public void stop(BundleContext context) throws Exception {
		plugin = null;
		super.stop(context);
	}

	/**
	 * Returns the shared instance.
	 *
	 * @return The shared instance of ToolingReuseActivator
	 */
	public static ToolingReuseUIActivator getDefault() {
		return plugin;
	}

	/**
	 * Returns the image descriptor for the given icon file.
	 *
	 * @param path The path to the icon file of the image descriptor
	 * @return The image descriptor
	 */
	public static ImageDescriptor getImageDescriptor(String path) {
		return imageDescriptorFromBundle(PLUGIN_ID, path).orElse(null);
	}

}
